__description__ = "a python module housing ligolw-based reporters"
__author__ = "Patrick Godwin (patrick.godwin@ligo.org)"
__doc__ = "\n\n".join([__description__, __author__])

#-------------------------------------------------

from ligo.lw import ligolw
from ligo.lw import lsctables
from ligo.lw import utils as ligolw_utils
from ligo.lw.utils import segments as ligolw_segments

from ... import hookimpl
from . import DiskReporter


#-------------------------------------------------
### reporter implementations

class LIGOLWSegmentReporter(DiskReporter):
    """
    a variant of DiskReporter that expects to only deal with ligolw segments in XML form.
    """
    _suffix = 'xml.gz'

    def __init__(self, *args, **kwargs):
        DiskReporter.__init__(self, *args, **kwargs)
        self.instrument = self.kwargs.pop('instrument') if 'instrument' in self.kwargs else 'None'

    def _write(self, path, segs, nickname='name', **kwargs):
        # create xmldoc and process
        xmldoc = ligolw.Document()
        xmldoc.appendChild(ligolw.LIGO_LW())
        process = lsctables.Process(process_id = lsctables.ProcessTable.get_next_id())

        # store segments into xmldoc
        with ligolw_segments.LigolwSegments(xmldoc, process) as xmlsegments:
            xmlsegments.insert_from_segmentlistdict({self.instrument: segs}, nickname)

        # save to disk
        ligolw_utils.write_filename(xmldoc, path, gz=path.endswith('gz'))

    def _read(self, path):
        segs = ligolw_segments.segmenttable_get_by_name(ligolw_utils.load_filename(path, contenthandler=ligolw_segments.LIGOLWContentHandler), path).coalesce()
        return segs[self.instrument]


#-------------------------------------------------
### plugin implementations

@hookimpl
def get_reporters():
    return {"segment:ligolw": LIGOLWSegmentReporter}
